pub type UndecodableDelivery<L = InsertOrder> = Delivery<L, UndecodableEventError>;Expand description
An undecodable persistent event as delivered on lane L — the Err arm of
every persistent stream, at the position the event occupies.
Aliased Type
pub struct UndecodableDelivery<L = InsertOrder> { /* private fields */ }Trait Implementations
Sourceimpl<L> Display for UndecodableDelivery<L>where
L: Lane,
impl<L> Display for UndecodableDelivery<L>where
L: Lane,
Sourceimpl<L> Error for UndecodableDelivery<L>where
L: Lane,
impl<L> Error for UndecodableDelivery<L>where
L: Lane,
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()